JsonEncoder

Struct JsonEncoder 

pub struct JsonEncoder<T> { /* private fields */ }
Available on crate feature std only.
NDJson encoder.

Implementations

Source

impl<T> JsonEncoder<T>

pub fn new() -> Self

Source

impl<T> JsonEncoder<T>

pub fn new_continued() -> Self

Use JsonEncoder::new for new streams. This constructor can be used if you wish to start the strema with a newline because you are continuing to write to a stream where you left of.