ServiceInput

Struct ServiceInput 

pub struct ServiceInput<T> {
    pub input: T,
    pub extensions: Extensions,
}
Available on crate feature std only.
A generic service input that implements all rama traits conditionally

This input type can be used in places where you need a request/stream that implements things such as ExtensionsRef without having to create a custom type for it.

This is mainly useful for testing or less import request types. In most cases you should create a new type that implements all the needed traits, but that is focussed specifically on that use case.

Fields

input: Textensions: Extensions

Implementations

Source

impl<T> ServiceInput<T>

pub fn new(input: T) -> Self