pub struct Uninit<B> { /* private fields */ }Available on crate feature
std only.Expand description
A read-target view of a buffer’s writable spare [buf_len, capacity): reading
into it appends to the underlying (the view’s offset 0 is the underlying’s
buf_len). Created by IoBufMut::uninit; recover the buffer with
into_inner.
Implementations
Sourceimpl<B> Uninit<B>
impl<B> Uninit<B>
Sourcepub fn into_inner(self) -> B
pub fn into_inner(self) -> B
Recover the underlying buffer, with whatever was read into the spare now part of its initialized region.