pub struct JsonEncoder<T> { /* private fields */ }Available on crate feature
std only.Expand description
NDJson encoder.
Implementations
Sourceimpl<T> JsonEncoder<T>
impl<T> JsonEncoder<T>
Sourceimpl<T> JsonEncoder<T>
impl<T> JsonEncoder<T>
Sourcepub fn new_continued() -> Self
pub fn new_continued() -> Self
Use JsonEncoder::new for new streams.
This constructor can be used if you wish to start
the strema with a newline because you are continuing
to write to a stream where you left of.